package com.microsoft.trouterclient;

/**
 * Interface for a listener that receives and responds to Trouter messages.
 */
public interface ITrouterListener {
    /**
    * Called when the service URL that the Trouter client is reachable via changes.
    * This method is invoked on an internal thread. Please do not block it with any longer activities.
    * @param routingPath a case sensitive string which downstream clients should use to contact this agent
    * @param newPublicUrl whether the routingPath reflects the first connect call with this PublicURL
    * @param missedRequests whether the client MAY have missed requests for the agent while it was disconnected.
    */
    public void onTrouterConnected(String routingPath, boolean newPublicUrl, boolean missedRequests);

    /**
    * Signals that Trouter client has become disconnected from the Trouter service.
    * This method is invoked on an internal thread. Please do not block it with any longer activities.
    */
    public void onTrouterDisconnected();

    /**
    * Called when a request is identified for this listener based on the routing path.
    * This method is invoked on an internal thread. Please do not block it with any longer activities.
    * If you don't respond the request in time, the implementation will reply with a default HTTP 504 response after
    * some timeout.
    * @param request A request containing caller's details, as received by the server.
    * @param response Response object to be filled in and sent by the client.
    */
    public void onTrouterRequest(ITrouterRequest request, ITrouterResponse response);

    /**
    * Called when a response has been sent.
    * Can be useful when you are waiting on network I/O completion.
    * This method is invoked on an internal thread. Please do not block it with any longer activities.
    * @param response Trouter response for which this callback was intended; you should not use anything else than its
    *                 getID() method at this time.
    * @param isSuccess true if the response was sent successfully, false otherwise.
    */
    public void onTrouterResponseSent(ITrouterResponse response, boolean isSuccess);
};
